.. image:: ../artwork/logo.png
  :width: 200px
  :align: right

Support
=======

The Graphcat documentation:

* http://graphcat.readthedocs.io

Visit our GitHub repository for access to source code, test results, issue
tracker, and the wiki:

* http://github.com/shead-custom-design/graphcat

Our coverage statistics are updated automatically when modifications are
committed:

* https://coveralls.io/r/shead-custom-design/graphcat

For Graphcat questions, comments, or suggestions, get in touch with the team at:

* https://github.com/shead-custom-design/graphcat/discussions

Otherwise, you can contact Tim directly:

* Timothy M. Shead - `tim@shead-custom-design <mailto:tim@shead-custom-design?subject=Graphcat>`_
